==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QDynamicPropertyChangeEvent_shell.cpp <==
#include "QDynamicPropertyChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDynamicPropertyChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDynamicPropertyChangeEvent")
    QDynamicPropertyChangeEvent *_ptr = reinterpret_cast<QDynamicPropertyChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDynamicPropertyChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDynamicPropertyChangeEvent_shell) ); }

jmethodID QDynamicPropertyChangeEvent_shell::__shell_javaMethod(int pos) const { return QDynamicPropertyChangeEvent_shell::__shell()->javaMethod(typeid(QDynamicPropertyChangeEvent), pos); }

// emitting (writeShellConstructor)
QDynamicPropertyChangeEvent_shell::QDynamicPropertyChangeEvent_shell(const QByteArray& name0)
    : QDynamicPropertyChangeEvent(name0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent_shell(const QByteArray& name0)", QDynamicPropertyChangeEvent_shell::__shell())
    QDynamicPropertyChangeEvent_shell::__shell()->constructed(typeid(QDynamicPropertyChangeEvent));
}

// emitting (writeShellDestructor)
QDynamicPropertyChangeEvent_shell::~QDynamicPropertyChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDynamicPropertyChangeEvent::~QDynamicPropertyChangeEvent()", QDynamicPropertyChangeEvent_shell::__shell())
    QDynamicPropertyChangeEvent_shell::__shell()->destructed(typeid(QDynamicPropertyChangeEvent));
}

void QDynamicPropertyChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDynamicPropertyChangeEvent_shell*>(ptr)->QDynamicPropertyChangeEvent_shell::__shell()->tryDeleteShell(typeid(QDynamicPropertyChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QDynamicPropertyChangeEvent(QByteArray)
void __qt_construct_QDynamicPropertyChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDynamicPropertyChangeEvent(QByteArray)")
    jobject name0 = __java_arguments[0].l;
    const QByteArray& __qt_name0 = qtjambi_cast<const QByteArray& >(__jni_env, name0);
    QDynamicPropertyChangeEvent *__qt_this = new(__qtjambi_ptr) QDynamicPropertyChangeEvent_shell(__qt_name0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDynamicPropertyChangeEvent_shell
void __qt_destruct_QDynamicPropertyChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDynamicPropertyChangeEvent")
    reinterpret_cast<QDynamicPropertyChangeEvent_shell*>(ptr)->~QDynamicPropertyChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_initialize_1native__Lio_qt_core_QDynamicPropertyChangeEvent_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject name0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QByteArray)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = name0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDynamicPropertyChangeEvent_0, sizeof(QDynamicPropertyChangeEvent_shell), typeid(QDynamicPropertyChangeEvent), true, &deleter_QDynamicPropertyChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDynamicPropertyChangeEvent::propertyName()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_propertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDynamicPropertyChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDynamicPropertyChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDynamicPropertyChangeEvent::propertyName()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->propertyName();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDynamicPropertyChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDynamicPropertyChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QDynamicPropertyChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDynamicPropertyChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDynamicPropertyChangeEvent>("QDynamicPropertyChangeEvent", "io/qt/core/QDynamicPropertyChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDynamicPropertyChangeEvent, {
        ConstructorInfo(&__qt_construct_QDynamicPropertyChangeEvent_0, "Lio/qt/core/QByteArray;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDynamicPropertyChangeEvent);
    registerSizeOfShell(typeId, sizeof(QDynamicPropertyChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDynamicPropertyChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QDynamicPropertyChangeEvent_shell.cpp <==
#include "QDynamicPropertyChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDynamicPropertyChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDynamicPropertyChangeEvent")
    QDynamicPropertyChangeEvent *_ptr = reinterpret_cast<QDynamicPropertyChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDynamicPropertyChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDynamicPropertyChangeEvent_shell) ); }

jmethodID QDynamicPropertyChangeEvent_shell::__shell_javaMethod(int pos) const { return QDynamicPropertyChangeEvent_shell::__shell()->javaMethod(typeid(QDynamicPropertyChangeEvent), pos); }

// emitting (writeShellConstructor)
QDynamicPropertyChangeEvent_shell::QDynamicPropertyChangeEvent_shell(const QByteArray& name0)
    : QDynamicPropertyChangeEvent(name0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent_shell(const QByteArray& name0)", QDynamicPropertyChangeEvent_shell::__shell())
    QDynamicPropertyChangeEvent_shell::__shell()->constructed(typeid(QDynamicPropertyChangeEvent));
}

QDynamicPropertyChangeEvent_shell::QDynamicPropertyChangeEvent_shell(const QDynamicPropertyChangeEvent& other0)
    : QDynamicPropertyChangeEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent_shell(const QDynamicPropertyChangeEvent& other0)", QDynamicPropertyChangeEvent_shell::__shell())
    QDynamicPropertyChangeEvent_shell::__shell()->constructed(typeid(QDynamicPropertyChangeEvent));
}

// emitting (writeShellDestructor)
QDynamicPropertyChangeEvent_shell::~QDynamicPropertyChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDynamicPropertyChangeEvent::~QDynamicPropertyChangeEvent()", QDynamicPropertyChangeEvent_shell::__shell())
    QDynamicPropertyChangeEvent_shell::__shell()->destructed(typeid(QDynamicPropertyChangeEvent));
}

void QDynamicPropertyChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDynamicPropertyChangeEvent_shell*>(ptr)->QDynamicPropertyChangeEvent_shell::__shell()->tryDeleteShell(typeid(QDynamicPropertyChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QDynamicPropertyChangeEvent(QByteArray)
void __qt_construct_QDynamicPropertyChangeEvent_cref_QByteArray(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDynamicPropertyChangeEvent(QByteArray)")
    jobject name0 = __java_arguments[0].l;
    const QByteArray& __qt_name0 = qtjambi_cast<const QByteArray& >(__jni_env, name0);
    QDynamicPropertyChangeEvent *__qt_this = new(__qtjambi_ptr) QDynamicPropertyChangeEvent_shell(__qt_name0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QByteArray)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_initialize_1native__Lio_qt_core_QDynamicPropertyChangeEvent_2Lio_qt_core_QByteArray_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject name0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QByteArray)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = name0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDynamicPropertyChangeEvent_cref_QByteArray, sizeof(QDynamicPropertyChangeEvent_shell), typeid(QDynamicPropertyChangeEvent), true, &deleter_QDynamicPropertyChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)
void __qt_construct_QDynamicPropertyChangeEvent_cref_QDynamicPropertyChangeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)")
    jobject other0 = __java_arguments[0].l;
    const QDynamicPropertyChangeEvent& __qt_other0 = qtjambi_cast<const QDynamicPropertyChangeEvent& >(__jni_env, other0);
    QDynamicPropertyChangeEvent *__qt_this = new(__qtjambi_ptr) QDynamicPropertyChangeEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_initialize_1native__Lio_qt_core_QDynamicPropertyChangeEvent_2Lio_qt_core_QDynamicPropertyChangeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(QDynamicPropertyChangeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDynamicPropertyChangeEvent_cref_QDynamicPropertyChangeEvent, sizeof(QDynamicPropertyChangeEvent_shell), typeid(QDynamicPropertyChangeEvent), true, &deleter_QDynamicPropertyChangeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDynamicPropertyChangeEvent_shell
void __qt_destruct_QDynamicPropertyChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDynamicPropertyChangeEvent")
    reinterpret_cast<QDynamicPropertyChangeEvent_shell*>(ptr)->~QDynamicPropertyChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDynamicPropertyChangeEvent::propertyName()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_propertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDynamicPropertyChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDynamicPropertyChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDynamicPropertyChangeEvent::propertyName()const", __qt_this)
        QByteArray __qt_return_value = __qt_this->propertyName();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDynamicPropertyChangeEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDynamicPropertyChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDynamicPropertyChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QDynamicPropertyChangeEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDynamicPropertyChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDynamicPropertyChangeEvent>("QDynamicPropertyChangeEvent", "io/qt/core/QDynamicPropertyChangeEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDynamicPropertyChangeEvent, {
        ConstructorInfo(&__qt_construct_QDynamicPropertyChangeEvent_cref_QByteArray, "Lio/qt/core/QByteArray;")
       ,ConstructorInfo(&__qt_construct_QDynamicPropertyChangeEvent_cref_QDynamicPropertyChangeEvent, "Lio/qt/core/QDynamicPropertyChangeEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDynamicPropertyChangeEvent);
    registerSizeOfShell(typeId, sizeof(QDynamicPropertyChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDynamicPropertyChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
